pub enum Change {
Created {
path: PathBuf,
},
Removed {
path: PathBuf,
},
Renamed {
from: PathBuf,
to: PathBuf,
},
Modified {
path: PathBuf,
},
Rescan,
}Expand description
A change that happened on disk, in model vocabulary. Produced by
super::watcher from raw notify events and by file operations.
Variants