pub fn load_omarchy_theme() -> Option<OmarchyTheme>Expand description
Read the active Omarchy theme, or None when Omarchy isn’t installed or its
state directory is unreadable.
pub fn load_omarchy_theme() -> Option<OmarchyTheme>Read the active Omarchy theme, or None when Omarchy isn’t installed or its
state directory is unreadable.