pub fn load_omarchy_theme_from(dir: &Path) -> Option<OmarchyTheme>Expand description
Read an Omarchy theme from an explicit directory (tests). The font is looked up through fontconfig.
pub fn load_omarchy_theme_from(dir: &Path) -> Option<OmarchyTheme>Read an Omarchy theme from an explicit directory (tests). The font is looked up through fontconfig.