pub fn omarchy_stylesheet() -> StylesheetExpand description
Build the stylesheet for Omarchy’s active theme, falling back to the shipped default when no theme can be read.
pub fn omarchy_stylesheet() -> StylesheetBuild the stylesheet for Omarchy’s active theme, falling back to the shipped default when no theme can be read.