pub enum BookmarkEvent {
Open(PathBuf),
Edit(usize),
Delete(usize),
Action {
path: PathBuf,
target: ShortcutTarget,
},
}Expand description
What the user did in the bookmarks view.
Variants
Open(PathBuf)
Jump this pane to the bookmark’s directory.
Edit(usize)
Edit the bookmark at this index in the list.
Delete(usize)
Delete the bookmark at this index in the list.
Action
Run an inherited (directory) context action against path without
opening it.