pub enum ToolbarOutput {
OpenFolder,
NavigateTo(PathBuf),
FilterRequested,
SplitView,
Collapse,
ClosePane,
PaneItem(ShortcutTarget),
}Expand description
Intent produced by the toolbar, forwarded to the app.
Variants
OpenFolder
The user asked to pick a folder to browse (from the hamburger menu).
The user pressed Enter in the path entry with a (possibly new) path.
FilterRequested
The user asked (from the top-bar menu) to open the panel filter bar.
SplitView
The user requested a new split pane.
Collapse
The user requested to hide this pane’s entire side (the whole dock).
ClosePane
The user requested to close this pane (exits the app on the last one).
PaneItem(ShortcutTarget)
A configurable pane-menu item resolved to a tree builtin or custom command. The app routes builtins to the pane’s tree and reports errors for commands.