pub fn bind() -> Result<UnixListener>Expand description
Bind the instance socket as the (single) server.
If the path is already in use, a connect is attempted to distinguish a live server (in which case we must not become a second instance — the socket is left alone and the error returned) from a stale socket left by a crashed instance (which is removed and the bind retried).