pub enum BookmarkEvent {
Open(PathBuf),
Edit(usize),
Delete(usize),
Hide,
}Expand description
What the user did in the bookmarks section.
Variants
Open(PathBuf)
Open a new pane at the bookmark’s directory.
Edit(usize)
Edit the bookmark at this index in the list.
Delete(usize)
Delete the bookmark at this index in the list.
Hide
Hide the bookmarks strip (the close button; same as the toggle action).